@@ -90,6 +90,9 @@ GLOBAL char **authorization_name;
 GLOBAL char **password;
 GLOBAL char **src_dir;
 GLOBAL char **dest_dir;
+GLOBAL int *host_use_SSL;
+GLOBAL int *host_use_SSL_verify;
+GLOBAL char **host_use_SSL_cafile;
 GLOBAL cfgList **ignore_local_dir;
 GLOBAL cfgList **ignore_local_file;
 GLOBAL cfgList **ignore_remote_dir;
